aboutsummaryrefslogtreecommitdiffstats
path: root/lib/web3.js
diff options
context:
space:
mode:
Diffstat (limited to 'lib/web3.js')
-rw-r--r--lib/web3.js7
1 files changed, 4 insertions, 3 deletions
diff --git a/lib/web3.js b/lib/web3.js
index c99c76421..c3126afc4 100644
--- a/lib/web3.js
+++ b/lib/web3.js
@@ -250,10 +250,11 @@ var web3 = {
},
/// @param filter may be a string, object or event
- /// @param indexed is optional, this may be an object with optional event indexed params
- watch: function (filter, indexed) {
+ /// @param indexed is optional, this is an object with optional event indexed params
+ /// @param options is optional, this is an object with optional event options ('max'...)
+ watch: function (filter, indexed, options) {
if (filter._isEvent) {
- return filter(indexed);
+ return filter(indexed, options);
}
return new web3.filter(filter, ethWatch);
}